@@ -6,7 +6,7 @@ from .fixtures import (  # noqa: imported so that pytest can find the fixtures
     data_fixtures,
     fake_utcnow,
     fake_uuid4,
-    moto_sagemaker,
     moto_session,
     sagemaker,
 )
+from .test_cli import cli_helper  # noqa
