@@ -12,6 +12,7 @@ from ml2p import __version__ as ml2p_version
 from ml2p.core import (
     S3URL,
     Model,
+    ModelDatasetGenerator,
     ModellingSubCfg,
     ModelPredictor,
     ModelTrainer,
@@ -77,7 +78,7 @@ class TestSageMakerEnvTrain:
         assert env.env_type == env.TRAIN
         assert env.training_job_name == "test-train-1.2.3"
         assert env.model_version is None
-        assert env.record_invokes is None
+        assert env.record_invokes is False
         assert env.project == "test-project"
 
     def test_create_env_without_project_name(self, sagemaker):
@@ -136,6 +137,16 @@ class TestSageMakerEnvServe:
         env = sagemaker.serve(ML2P_RECORD_INVOKES="true")
         assert env.record_invokes is True
 
+    class TestSageMakerEnvGenerateDataset:
+        def test_basic_env(self, sagemaker):
+            env = sagemaker.dataset()
+            assert env.env_type == env.DATASET
+            assert env.dataset_name == "test-dataset-20220112"
+            assert env.model_version is None
+            assert env.record_invokes is False
+            assert env.training_job_name is None
+            assert env.project == "test-project"
+
 
 class TestSageMakerEnvLocal:
     def test_basic_env(self, sagemaker):
@@ -229,21 +240,6 @@ class TestSageMakerEnvLocal:
 
 
 class TestSageMakerEnvGeneric:
-    def test_hyperparameters(self, sagemaker):
-        sagemaker.ml_folder.mkdir("input").mkdir("config").join(
-            "hyperparameters.json"
-        ).write('{"param": "\\"value\\""}')
-        assert sagemaker.generic().hyperparameters() == {"param": "value"}
-
-    def test_nested_hyperparameters(self, sagemaker):
-        sagemaker.ml_folder.mkdir("input").mkdir("config").join(
-            "hyperparameters.json"
-        ).write('{"a.b": "1", "a.c": "2"}')
-        assert sagemaker.generic().hyperparameters() == {"a": {"b": 1, "c": 2}}
-
-    def test_missing_hyperparameters_file(self, sagemaker):
-        assert sagemaker.generic().hyperparameters() == {}
-
     def test_resourceconfig(self, sagemaker):
         sagemaker.ml_folder.mkdir("input").mkdir("config").join(
             "resourceconfig.json"
@@ -418,6 +414,39 @@ class TestModelPredictor:
         }
 
 
+class TestModelDatasetGenerator:
+    def test_create(self, sagemaker):
+        env = sagemaker.dataset()
+        dataset_generator = ModelDatasetGenerator(env)
+        assert dataset_generator.env is env
+
+    def test_upload_to_s3(self, sagemaker, tmpdir):
+        dataset_generator = ModelDatasetGenerator(sagemaker.dataset())
+        my_file = tmpdir / "dataset.txt"
+        with tmpdir.as_cwd():
+            with my_file.open("w") as f:
+                f.write("This is my dataset!")
+            dataset_generator.upload_to_s3("dataset.txt")
+        s3_file = sagemaker.s3.get_object(
+            Bucket="foo", Key="bar/datasets/test-dataset-20220112/dataset.txt"
+        )
+        assert s3_file["Body"].read().decode() == "This is my dataset!"
+
+    def test_upload_to_s3_custom_directory(self, sagemaker, tmpdir):
+        dataset_generator = ModelDatasetGenerator(sagemaker.dataset())
+        my_directory = tmpdir.join("my_directory").mkdir()
+        my_file = my_directory / "my_other_dataset.txt"
+        with tmpdir.as_cwd():
+            with my_file.open("w") as f:
+                f.write("This is my other dataset!")
+            dataset_generator.upload_to_s3("./my_directory/my_other_dataset.txt")
+        s3_file = sagemaker.s3.get_object(
+            Bucket="foo",
+            Key="bar/datasets/test-dataset-20220112/my_other_dataset.txt",
+        )
+        assert s3_file["Body"].read().decode() == "This is my other dataset!"
+
+
 class TestModel:
     def test_trainer_not_set(self, sagemaker):
         with pytest.raises(ValueError) as exc_info:
@@ -448,3 +477,20 @@ class TestModel:
         predictor = MyModel().predictor(env)
         assert predictor.__class__ is ModelPredictor
         assert predictor.env is env
+
+    def test_datatest_generator_not_set(self, sagemaker):
+        with pytest.raises(ValueError) as exc_info:
+            Model().dataset_generator(sagemaker.dataset())
+        assert (
+            str(exc_info.value)
+            == ".DATASET_GENERATOR should be an instance of ModelDatasetGenerator"
+        )
+
+    def test_datatest_generator_set(self, sagemaker):
+        class MyModel(Model):
+            DATASET_GENERATOR = ModelDatasetGenerator
+
+        env = sagemaker.dataset()
+        dataset_generator = MyModel().dataset_generator(env)
+        assert dataset_generator.__class__ is ModelDatasetGenerator
+        assert dataset_generator.env is env
